==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/template/barnraiser_01/node_structure.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_node_rules'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_node_rules'];?><br />
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_structure'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_node_structure'];?><br />
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_role'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table cellpadding="2" cellspacing="0" border="0" width="100%">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_role'];?><br />
						</td>
						<td valign="top">
							<?php 
							if (isset($user['role_id'])) {
								echo $lang['arr_acs']['role'][$user['role_id']];
							}
							else {
								echo $lang['arr_acs']['role'][0]; //visitor
							}
								?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_membership_number'];?><br />
						</td>
						<td valign="top">
							<?php 
							if (isset($user['user_number'])) {
								echo $user['user_number'];
							}
							?><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_administration'];?><br />
		</div>
		
		<div class="box_mid">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<?php echo $lang['txt_administration'];?><br />
					</td>
				</tr>
			</table>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_statistics'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" width="100%" cellspacing="0" cellpadding="4">
					<?php
					if (!empty($statistics)) {
					if (isset($statistics['total_users'])) {
					?>
					<tr>
						<td>
							<?php echo $lang['txt_statistic_total_users'];?><br />
						</td>
						<td align="right">
							<?php echo $statistics['total_users'];?><br />
						</td>
					</tr>
					<?php 
					}
					
					if (isset($statistics['total_online_users'])) {
					?>
					<tr>
						<td>
							<?php echo $lang['txt_statistic_total_users_online'];?><br />
						</td>
						<td align="right">
							<?php echo $statistics['total_online_users'];?><br />
						</td>
					</tr>
					<?php 
					}
					}
					else {
					?>
					<tr>
						<td colspan="3">
							<?php echo $lang['err_no_statistics'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_system'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
					<tr>
						<td>
							<?php echo $lang['txt_version'];?><br />
						</td>
						<td>
							<?php echo $release['version'];?><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php echo $lang['txt_release_date'];?><br />
						</td>
						<td>
							<?php echo $release['release_date'];?><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php echo $lang['txt_install_date'];?><br />
						</td>
						<td>
							<?php echo $release['install_date'];?><br />
						</td>
					</tr>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr>
						<td>
							<?php echo $lang['txt_savannah'];?><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

==> aroundme_0_6_9.zip: aroundme_0_6_9/aroundme/template/barnraiser_01/node_structure.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_node_rules'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_node_rules'];?><br />
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_structure'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_node_structure'];?><br />
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_role'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table cellpadding="2" cellspacing="0" border="0" width="100%">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_role'];?><br />
						</td>
						<td valign="top">
							<?php 
							if (isset($user['role_id'])) {
								echo $lang['arr_acs']['role'][$user['role_id']];
							}
							else {
								echo $lang['arr_acs']['role'][$default_role_id]; //visitor
							}
								?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_membership_number'];?><br />
						</td>
						<td valign="top">
							<?php 
							if (isset($user['user_number'])) {
								echo $user['user_number'];
							}
							?><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_administration'];?><br />
		</div>
		
		<div class="box_mid">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<?php echo $lang['txt_administration'];?><br />
					</td>
				</tr>
			</table>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_statistics'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" width="100%" cellspacing="0" cellpadding="4">
					<?php
					if (!empty($statistics)) {
					if (isset($statistics['total_users'])) {
					?>
					<tr>
						<td>
							<?php echo $lang['txt_statistic_total_users'];?><br />
						</td>
						<td align="right">
							<?php echo $statistics['total_users'];?><br />
						</td>
					</tr>
					<?php 
					}
					
					if (isset($statistics['total_online_users'])) {
					?>
					<tr>
						<td>
							<?php echo $lang['txt_statistic_total_users_online'];?><br />
						</td>
						<td align="right">
							<?php echo $statistics['total_online_users'];?><br />
						</td>
					</tr>
					<?php 
					}
					}
					else {
					?>
					<tr>
						<td colspan="3">
							<?php echo $lang['err_no_statistics'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_system'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
					<tr>
						<td>
							<?php echo $lang['txt_version'];?><br />
						</td>
						<td>
							<?php echo $release['version'];?><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php echo $lang['txt_release_date'];?><br />
						</td>
						<td>
							<?php echo $release['release_date'];?><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php echo $lang['txt_install_date'];?><br />
						</td>
						<td>
							<?php echo $release['install_date'];?><br />
						</td>
					</tr>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr>
						<td>
							<?php echo $lang['txt_savannah'];?><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
